==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wseventing/model/SubscriptionEnd.java <==

package org.somda.sdc.dpws.soap.wseventing.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="SubscriptionManager" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/&gt;
 *         &lt;element name="Status" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}OpenSubscriptionEndCodeType"/&gt;
 *         &lt;element name="Reason" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}LanguageSpecificStringType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "subscriptionManager",
    "status",
    "reason",
    "any"
})
@XmlRootElement(name = "SubscriptionEnd", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
public class SubscriptionEnd implements ToString2
{

    @XmlElement(name = "SubscriptionManager", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected EndpointReferenceType subscriptionManager;
    @XmlElement(name = "Status", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected String status;
    @XmlElement(name = "Reason", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected List<LanguageSpecificStringType> reason;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der subscriptionManager-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getSubscriptionManager() {
        return subscriptionManager;
    }

    /**
     * Legt den Wert der subscriptionManager-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setSubscriptionManager(EndpointReferenceType value) {
        this.subscriptionManager = value;
    }

    /**
     * Ruft den Wert der status-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStatus() {
        return status;
    }

    /**
     * Legt den Wert der status-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStatus(String value) {
        this.status = value;
    }

    /**
     * Gets the value of the reason property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the reason property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReason().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LanguageSpecificStringType }
     * 
     * 
     */
    public List<LanguageSpecificStringType> getReason() {
        if (reason == null) {
            reason = new ArrayList<LanguageSpecificStringType>();
        }
        return this.reason;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setReason(List<LanguageSpecificStringType> value) {
        this.reason = null;
        if (value!= null) {
            List<LanguageSpecificStringType> draftl = this.getReason();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SubscriptionEnd that = ((SubscriptionEnd) object);
        {
            EndpointReferenceType leftSubscriptionManager;
            leftSubscriptionManager = this.getSubscriptionManager();
            EndpointReferenceType rightSubscriptionManager;
            rightSubscriptionManager = that.getSubscriptionManager();
            if (this.subscriptionManager!= null) {
                if (that.subscriptionManager!= null) {
                    if (!leftSubscriptionManager.equals(rightSubscriptionManager)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.subscriptionManager!= null) {
                    return false;
                }
            }
        }
        {
            String leftStatus;
            leftStatus = this.getStatus();
            String rightStatus;
            rightStatus = that.getStatus();
            if (this.status!= null) {
                if (that.status!= null) {
                    if (!leftStatus.equals(rightStatus)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.status!= null) {
                    return false;
                }
            }
        }
        {
            List<LanguageSpecificStringType> leftReason;
            leftReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            List<LanguageSpecificStringType> rightReason;
            rightReason = (((that.reason!= null)&&(!that.reason.isEmpty()))?that.getReason():null);
            if ((this.reason!= null)&&(!this.reason.isEmpty())) {
                if ((that.reason!= null)&&(!that.reason.isEmpty())) {
                    if (!leftReason.equals(rightReason)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.reason!= null)&&(!that.reason.isEmpty())) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theSubscriptionManager;
            theSubscriptionManager = this.getSubscriptionManager();
            if (this.subscriptionManager!= null) {
                currentHashCode += theSubscriptionManager.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theStatus;
            theStatus = this.getStatus();
            if (this.status!= null) {
                currentHashCode += theStatus.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<LanguageSpecificStringType> theReason;
            theReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            if ((this.reason!= null)&&(!this.reason.isEmpty())) {
                currentHashCode += theReason.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theSubscriptionManager;
            theSubscriptionManager = this.getSubscriptionManager();
            strategy.appendField(locator, this, "subscriptionManager", buffer, theSubscriptionManager, (this.subscriptionManager!= null));
        }
        {
            String theStatus;
            theStatus = this.getStatus();
            strategy.appendField(locator, this, "status", buffer, theStatus, (this.status!= null));
        }
        {
            List<LanguageSpecificStringType> theReason;
            theReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            strategy.appendField(locator, this, "reason", buffer, theReason, ((this.reason!= null)&&(!this.reason.isEmpty())));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wseventing/model/SubscriptionEnd.java <==

package org.somda.sdc.dpws.soap.wseventing.model;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlAnyElement;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.somda.sdc.dpws.soap.wsaddressing.model.EndpointReferenceType;
import org.w3c.dom.Element;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="SubscriptionManager" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/&gt;
 *         &lt;element name="Status" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}OpenSubscriptionEndCodeType"/&gt;
 *         &lt;element name="Reason" type="{http://schemas.xmlsoap.org/ws/2004/08/eventing}LanguageSpecificStringType" maxOccurs="unbounded" minOccurs="0"/&gt;
 *         &lt;any processContents='lax' namespace='##other' maxOccurs="unbounded" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "subscriptionManager",
    "status",
    "reason",
    "any"
})
@XmlRootElement(name = "SubscriptionEnd", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
public class SubscriptionEnd implements ToString2
{

    @XmlElement(name = "SubscriptionManager", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected EndpointReferenceType subscriptionManager;
    @XmlElement(name = "Status", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing", required = true)
    protected String status;
    @XmlElement(name = "Reason", namespace = "http://schemas.xmlsoap.org/ws/2004/08/eventing")
    protected List<LanguageSpecificStringType> reason;
    @XmlAnyElement(lax = true)
    protected List<Object> any;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the subscriptionManager property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getSubscriptionManager() {
        return subscriptionManager;
    }

    /**
     * Sets the value of the subscriptionManager property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setSubscriptionManager(EndpointReferenceType value) {
        this.subscriptionManager = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getStatus() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setStatus(String value) {
        this.status = value;
    }

    /**
     * Gets the value of the reason property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the reason property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReason().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link LanguageSpecificStringType }
     * 
     * 
     */
    public List<LanguageSpecificStringType> getReason() {
        if (reason == null) {
            reason = new ArrayList<LanguageSpecificStringType>();
        }
        return this.reason;
    }

    /**
     * Gets the value of the any property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the any property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAny().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Element }
     * {@link Object }
     * 
     * 
     */
    public List<Object> getAny() {
        if (any == null) {
            any = new ArrayList<Object>();
        }
        return this.any;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public void setReason(List<LanguageSpecificStringType> value) {
        this.reason = null;
        if (value!= null) {
            List<LanguageSpecificStringType> draftl = this.getReason();
            draftl.addAll(value);
        }
    }

    public void setAny(List<Object> value) {
        this.any = null;
        if (value!= null) {
            List<Object> draftl = this.getAny();
            draftl.addAll(value);
        }
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final SubscriptionEnd that = ((SubscriptionEnd) object);
        {
            EndpointReferenceType leftSubscriptionManager;
            leftSubscriptionManager = this.getSubscriptionManager();
            EndpointReferenceType rightSubscriptionManager;
            rightSubscriptionManager = that.getSubscriptionManager();
            if (this.subscriptionManager!= null) {
                if (that.subscriptionManager!= null) {
                    if (!leftSubscriptionManager.equals(rightSubscriptionManager)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.subscriptionManager!= null) {
                    return false;
                }
            }
        }
        {
            String leftStatus;
            leftStatus = this.getStatus();
            String rightStatus;
            rightStatus = that.getStatus();
            if (this.status!= null) {
                if (that.status!= null) {
                    if (!leftStatus.equals(rightStatus)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.status!= null) {
                    return false;
                }
            }
        }
        {
            List<LanguageSpecificStringType> leftReason;
            leftReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            List<LanguageSpecificStringType> rightReason;
            rightReason = (((that.reason!= null)&&(!that.reason.isEmpty()))?that.getReason():null);
            if ((this.reason!= null)&&(!this.reason.isEmpty())) {
                if ((that.reason!= null)&&(!that.reason.isEmpty())) {
                    if (!leftReason.equals(rightReason)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.reason!= null)&&(!that.reason.isEmpty())) {
                    return false;
                }
            }
        }
        {
            List<Object> leftAny;
            leftAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            List<Object> rightAny;
            rightAny = (((that.any!= null)&&(!that.any.isEmpty()))?that.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    if (!leftAny.equals(rightAny)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if ((that.any!= null)&&(!that.any.isEmpty())) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            EndpointReferenceType theSubscriptionManager;
            theSubscriptionManager = this.getSubscriptionManager();
            if (this.subscriptionManager!= null) {
                currentHashCode += theSubscriptionManager.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theStatus;
            theStatus = this.getStatus();
            if (this.status!= null) {
                currentHashCode += theStatus.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<LanguageSpecificStringType> theReason;
            theReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            if ((this.reason!= null)&&(!this.reason.isEmpty())) {
                currentHashCode += theReason.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            if ((this.any!= null)&&(!this.any.isEmpty())) {
                currentHashCode += theAny.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            EndpointReferenceType theSubscriptionManager;
            theSubscriptionManager = this.getSubscriptionManager();
            strategy.appendField(locator, this, "subscriptionManager", buffer, theSubscriptionManager, (this.subscriptionManager!= null));
        }
        {
            String theStatus;
            theStatus = this.getStatus();
            strategy.appendField(locator, this, "status", buffer, theStatus, (this.status!= null));
        }
        {
            List<LanguageSpecificStringType> theReason;
            theReason = (((this.reason!= null)&&(!this.reason.isEmpty()))?this.getReason():null);
            strategy.appendField(locator, this, "reason", buffer, theReason, ((this.reason!= null)&&(!this.reason.isEmpty())));
        }
        {
            List<Object> theAny;
            theAny = (((this.any!= null)&&(!this.any.isEmpty()))?this.getAny():null);
            strategy.appendField(locator, this, "any", buffer, theAny, ((this.any!= null)&&(!this.any.isEmpty())));
        }
        return buffer;
    }

}
